ParserConfig

Struct ParserConfig 

pub struct ParserConfig {
    pub kind: String,
    pub options: Value,
}
Template parser definition

Fields

kind: String

Parser used to process the rendered template into API-compatible format

options: Value

Options for the parser

Implementations

Source

impl ParserConfig

pub fn new() -> Self

Create a new ParserConfig with default values.

pub fn from_json(json: &str, ctx: &LoadContext) -> Result<Self, Error>

Load ParserConfig from a JSON string.

pub fn from_yaml(yaml: &str, ctx: &LoadContext) -> Result<Self, Error>

Load ParserConfig from a YAML string.

pub fn load_from_value(value: &Value, ctx: &LoadContext) -> Self

Load ParserConfig from a serde_json::Value.

Calls ctx.process_input before field extraction.

pub fn to_value(&self, ctx: &SaveContext) -> Value

Serialize ParserConfig to a serde_json::Value.

Calls ctx.process_dict after serialization.

pub fn to_json(&self, ctx: &SaveContext) -> Result<String, Error>

Serialize ParserConfig to a JSON string.

pub fn to_yaml(&self, ctx: &SaveContext) -> Result<String, Error>

Serialize ParserConfig to a YAML string.

pub fn as_options_dict(&self) -> Option<&Map<String, Value>>

Returns typed reference to the map if the field is an object. Returns None if the field is null or not an object.