pub fn unwrap_structured(value: &Value) -> ValueExpand description
Unwrap a StructuredResult to just its data, or return the value as-is.
This is used by the pipeline to return clean data to the user while
preserving StructuredResult transport for cast().